netapp_ontap.models.snaplock_log_file API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.snaplock_log_file`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class SnaplockLogFileSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the SnaplockLogFile object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `archive PATCH`

    Archive the specified SnapLock log file for the given base_name, and create a new log file. If base_name is not mentioned, archive all log files.

  `base_name GET POST PATCH`

    Base name of log file

    Valid choices:

    - legal_hold
    - privileged_delete
    - system
  `expiry_time GET`

    Expiry time of the log file in date-time format. Value '9999-12-31T00:00:00Z' indicates infinite expiry time.

    Example: 2058-06-04T19:00:00.000+0000

  `links GET`

    The links field of the snaplock_log_file.

  `path GET`

    Absolute path of the log file in the volume

    Example: /snaplock_log/system_logs/20180822_005947_GMT-present

  `size GET`

    Size of the log file in bytes

    Example: 20000